@@ -21,7 +21,7 @@ auto ReadDataFrameArgs = r::List::create( r::_["path"] = "",
                                           r::_["file"] = "" );
 
 auto MakeBlockArgs = r::List::create( 
-    r::_["pyInput"]     = r::DataFrame(),
+    r::_["dataFrame"]   = r::DataFrame(),
     r::_["E"]           = 0,
     r::_["tau"]         = -1,
     r::_["columnNames"] = std::vector<std::string>() );
@@ -29,7 +29,7 @@ auto MakeBlockArgs = r::List::create(
 auto EmbedArgs = r::List::create( 
     r::_["path"]     = std::string(""),
     r::_["dataFile"] = std::string(""),
-    r::_["pyInput"]  = r::DataFrame(),
+    r::_["dataFrame"]= r::DataFrame(),
     r::_["E"]        = 0,
     r::_["tau"]      = -1,
     r::_["columns"]  = std::string(""),
@@ -38,7 +38,7 @@ auto EmbedArgs = r::List::create(
 auto SimplexArgs = r::List::create( 
     r::_["pathIn"]          = std::string("./"),
     r::_["dataFile"]        = std::string(""),
-    r::_["pyInput"]         = r::DataFrame(),
+    r::_["dataFrame"]       = r::DataFrame(),
     r::_["pathOut"]         = std::string("./"),
     r::_["predictFile"]     = std::string(""),
     r::_["lib"]             = std::string(""),
@@ -57,7 +57,7 @@ auto SimplexArgs = r::List::create(
 auto SMapArgs = r::List::create( 
     r::_["pathIn"]          = std::string("./"),
     r::_["dataFile"]        = std::string("./"),
-    r::_["dataList"]        = r::DataFrame(),
+    r::_["dataFrame"]       = r::DataFrame(),
     r::_["pathOut"]         = std::string("./"),
     r::_["predictFile"]     = std::string(""),
     r::_["lib"]             = std::string(""),
@@ -66,8 +66,8 @@ auto SMapArgs = r::List::create(
     r::_["Tp"]              = 1,
     r::_["knn"]             = 0,
     r::_["tau"]             = -1,
-    r::_["exclusionRadius"] = 0,
     r::_["theta"]           = 0,
+    r::_["exclusionRadius"] = 0,
     r::_["columns"]         = std::string(""),
     r::_["target"]          = std::string(""),
     r::_["smapFile"]        = std::string(""),
@@ -79,7 +79,7 @@ auto SMapArgs = r::List::create(
 auto MultiviewArgs = r::List::create( 
     r::_["pathIn"]          = std::string("./"),
     r::_["dataFile"]        = std::string(""),
-    r::_["pyInput"]         = r::DataFrame(),
+    r::_["dataFrame"]       = r::DataFrame(),
     r::_["pathOut"]         = std::string("./"),
     r::_["predictFile"]     = std::string(""),
     r::_["lib"]             = std::string(""),
@@ -98,29 +98,30 @@ auto MultiviewArgs = r::List::create(
     r::_["numThreads"]      = 4 );
 
 auto CCMArgs = r::List::create( 
-    r::_["pathIn"]      = std::string("./"),
-    r::_["dataFile"]    = std::string(""),
-    r::_["pyInput"]     = r::DataFrame(),
-    r::_["pathOut"]     = std::string("./"),
-    r::_["predictFile"] = std::string(""),
-    r::_["E"]           = 0,
-    r::_["Tp"]          = 0,
-    r::_["knn"]         = 0,
-    r::_["tau"]         = -1,
-    r::_["columns"]     = std::string(""),
-    r::_["target"]      = std::string(""),
-    r::_["libSizes"]    = std::string(""),
-    r::_["sample"]      = 0,
-    r::_["random"]      = true,
-    r::_["replacement"] = false,
-    r::_["seed"]        = 0,
-    r::_["includeData"] = false,
-    r::_["verbose"]     = false );
+    r::_["pathIn"]          = std::string("./"),
+    r::_["dataFile"]        = std::string(""),
+    r::_["dataFrame"]       = r::DataFrame(),
+    r::_["pathOut"]         = std::string("./"),
+    r::_["predictFile"]     = std::string(""),
+    r::_["E"]               = 0,
+    r::_["Tp"]              = 0,
+    r::_["knn"]             = 0,
+    r::_["tau"]             = -1,
+    r::_["exlcusionRadius"] = 0,
+    r::_["columns"]         = std::string(""),
+    r::_["target"]          = std::string(""),
+    r::_["libSizes"]        = std::string(""),
+    r::_["sample"]          = 0,
+    r::_["random"]          = true,
+    r::_["replacement"]     = false,
+    r::_["seed"]            = 0,
+    r::_["includeData"]     = false,
+    r::_["verbose"]         = false );
     
 auto EmbedDimensionArgs = r::List::create( 
     r::_["pathIn"]      = std::string("./"),
     r::_["dataFile"]    = std::string(""),
-    r::_["pyInput"]     = r::DataFrame(),
+    r::_["dataFrame"]   = r::DataFrame(),
     r::_["pathOut"]     = std::string("./"),
     r::_["predictFile"] = std::string(""),
     r::_["lib"]         = std::string(""),
@@ -137,7 +138,7 @@ auto EmbedDimensionArgs = r::List::create(
 auto PredictIntervalArgs = r::List::create( 
     r::_["pathIn"]      = std::string("./"),
     r::_["dataFile"]    = std::string(""),
-    r::_["pyInput"]     = r::DataFrame(),
+    r::_["dataFrame"]   = r::DataFrame(),
     r::_["pathOut"]     = std::string("./"),
     r::_["predictFile"] = std::string(""),
     r::_["lib"]         = std::string(""),
@@ -154,7 +155,7 @@ auto PredictIntervalArgs = r::List::create(
 auto PredictNonlinearArgs = r::List::create( 
     r::_["pathIn"]      = std::string("./"),
     r::_["dataFile"]    = std::string(""),
-    r::_["pyInput"]     = r::DataFrame(),
+    r::_["dataFrame"]   = r::DataFrame(),
     r::_["pathOut"]     = std::string("./"),
     r::_["predictFile"] = std::string(""),
     r::_["lib"]         = std::string(""),
